@@ -1,6 +1,6 @@
 /***
 |''Name''|TiddlySpaceTiddlerIconsPlugin|
-|''Version''|0.7.0|
+|''Version''|0.7.1|
 |''Status''|@@beta@@|
 |''Author''|Jon Robson|
 |''Description''|Provides ability to render SiteIcons and icons that correspond to the home location of given tiddlers|
@@ -106,8 +106,6 @@ var originMacro = config.macros.tiddlerOrigin = {
 		"privateNotPublic_info": "This tiddler is currently public, with a different private revision. You are currently viewing the private version.\nIt is visible to all at:\n%2\nbut the content will differ depending on permissions.\n\n",
 		"shadow_info": "This tiddler is a special tiddler that is part of the TiddlySpace application. It has no uri.",
 		"unknownUser": "an unknown user",
-		"makePublic": "Make this tiddler public",
-		"makePrivate": "Make this tiddler private",
 		"deletePrivate": "Delete the private version of this tiddler",
 		"deletePublic": "Delete the public version of this tiddler",
 		publishPrivateDeletePrivate: "Are you sure you want to make this tiddler public?",
@@ -118,7 +116,11 @@ var originMacro = config.macros.tiddlerOrigin = {
 		moveToPrivateKeep: "Are you sure you want to make this tiddler and all its revisions private? It will no longer be publically available to non-members of the space.",
 		"publicConfirmDelete": "Are you sure you want to delete all the public revisions of this tiddler?",
 		"privateConfirmDelete": "Are you sure you want to delete all the private revisions of this tiddler?",
-		pleaseWait: "please wait.."
+		pleaseWait: "please wait..",
+		keepPublic: "keep public",
+		keepPrivate: "keep private",
+		makePublic: "make public",
+		makePrivate: "make private"
 	},
 	handler: function(place, macroName, params,wikifier, paramString, tiddler){
 		var adaptor = tiddler.getAdaptor();
@@ -206,9 +208,12 @@ var originMacro = config.macros.tiddlerOrigin = {
 		}
 	},
 	getOptions: function(params, paramString) {
+		var parsedParams = paramString.parseParams("name");
 		var options = {
-			labelOptions: originMacro._getLabelOptions(paramString.parseParams("name")),
-			imageOptions: imageMacro.getArguments(paramString, [])
+			labelOptions: originMacro._getLabelOptions(parsedParams),
+			imageOptions: imageMacro.getArguments(paramString, []),
+			noclick: parsedParams[0].interactive && 
+				parsedParams[0].interactive[0] == "no" ? true : false
 		};
 		return options;
 	},
@@ -277,7 +282,7 @@ var originMacro = config.macros.tiddlerOrigin = {
 	},
 	showPrivacyRoundel: function(thisTiddler, privacyType, button, options) {
 		// there is a public tiddler as well as the current tiddler!
-		// to do: not this is not enough.. we also need to check if the public tiddler is the same as..
+		// TODO: not this is not enough.. we also need to check if the public tiddler is the same as..
 		// .. the private tiddler to determine whether this is a draft
 		// use of hashes would be useful here.
 		$(button).empty();
@@ -315,14 +320,15 @@ var originMacro = config.macros.tiddlerOrigin = {
 		}
 		$(button).attr("title", tooltip);
 	},
-	confirm: function(ev, msg, onYes) {
+	confirm: function(ev, msg, onYes, options) {
+		options = options ? options : {};
 		onYes = onYes ? onYes : function(ev) {};
 		var btn = $(".originButton", $(ev.target).parents())[0];
 		var popup = Popup.create(btn);
 		$(popup).addClass("confirmationPopup");
 		$("<div />").addClass("message").text(msg).appendTo(popup);
-		$("<button />").addClass("button").text("yes").appendTo(popup).click(onYes);
-		$("<button />").addClass("button").text("no").click(function(ev) {
+		$("<button />").addClass("button").text(options.yesLabel || "yes").appendTo(popup).click(onYes);
+		$("<button />").addClass("button").text(options.noLabel || "no").click(function(ev) {
 			Popup.remove();
 		}).appendTo(popup);
 		Popup.show();
@@ -342,7 +348,7 @@ var originMacro = config.macros.tiddlerOrigin = {
 						title: tiddler.title,
 						fields: { "server.bag": privateBag }
 					}, false, onComplete);
-				});
+				}, { yesLabel: locale.makePrivate, noLabel: locale.keepPublic });
 			}
 		},
 		"private": function(ev, tiddler) {
@@ -365,7 +371,7 @@ var originMacro = config.macros.tiddlerOrigin = {
 						title: newTitle,
 						fields: { "server.bag": publicBag }
 					}, false, onComplete);
-				});
+				}, { yesLabel: locale.makePublic, noLabel: locale.keepPrivate });
 			}
 		}
 	}
