@@ -19,6 +19,7 @@ SVG icons are drawn from tiddlers titled {{{<command>.svg}}}
 In readonly mode a tiddler called {{{<command>ReadOnly.svg}}} will be used if it exists.
 !TODO
 * rename (IconToolbarPlugin?)
+* support more than one more popup menu in the toolbar.
 !Code
 ***/
 //{{{
@@ -55,11 +56,13 @@ macro.handler = function(place, macroName, params, wikifier,
 	if(parsedParams.more && parsedParams.more == "popup") {
 		// note we must override the onclick event like in createTiddlyButton
 		// otherwise the click event is the popup AND the slider
-		$(".moreCommand", place)[0].onclick = macro.onClickMorePopUp;
+		$(".moreCommand", place).each(function(i, el) {
+			el.onclick = macro.onClickMorePopUp;
+		});
+		// buttons that are after a less command should not be in more menu.
+		$(".lessCommand ~ .button", place).appendTo(place);
+		$(".lessCommand", place).remove();
 	}
-	$(".lessCommand ~ .button", place).appendTo(place);
-	$(".lessCommand", place).remove();
-	
 	return status;
 };
 
@@ -92,17 +95,19 @@ macro.augmentCommandButtons = function(toolbar) {
 macro.onClickMorePopUp = function(ev) {
 	ev = ev || window.event;
 	var sibling = this.nextSibling;
-	var commands = sibling.childNodes;
-	var popup = Popup.create(this);
-	addClass(popup ,"taggedTiddlerList");
-	for(var i = 0; i < commands.length; i++) {
-		var li = createTiddlyElement(popup, "li", null);
-		var oldCommand = commands[i];
-		var command = oldCommand.cloneNode(true);
-		command.onclick = oldCommand.onclick;
-		li.appendChild(command);
+	if(sibling) {
+		var commands = sibling.childNodes;
+		var popup = Popup.create(this);
+		addClass(popup, "taggedTiddlerList");
+		for(var i = 0; i < commands.length; i++) {
+			var li = createTiddlyElement(popup, "li", null);
+			var oldCommand = commands[i];
+			var command = oldCommand.cloneNode(true);
+			command.onclick = oldCommand.onclick;
+			li.appendChild(command);
+		}
+		Popup.show();
 	}
-	Popup.show();
 	ev.cancelBubble = true;
 	if(ev.stopPropagation) {
 		ev.stopPropagation();
