@@ -48,7 +48,7 @@ var macro = config.macros.TiddlySpaceMembers = {
 		this.space = new tiddlyweb.Space(space, host); // XXX: singleton
 		var mode = params[0];
 		var args = paramString.parseParams("anon",null,true,false,false);
-		var hideErrors = args.hideErrors ? true : false
+		var hideErrors = args.hideErrors ? true : false;
 		var container;
 		if(!readOnly) {
 			if(mode == "add") {
